@@ -21,7 +21,6 @@ public class SessionCheckerServiceImpl extends RemoteServiceServlet implements
 
 	private static final Logger _log = LoggerFactory.getLogger(SessionCheckerServiceImpl.class);
 
-	private static final String FIRST_TIME = "FIRST_TIME_DEV_MODE";
 
 	/**
 	 * the current ASLSession
@@ -37,30 +36,28 @@ public class SessionCheckerServiceImpl extends RemoteServiceServlet implements
 
 	@Override
 	public SessionInfoBean checkSession() {
-		if (isFirstTime() == null) 
-			setFirstTimeCheck(true);
-
-		ASLSession session = getASLSession();
-		if (session == null) {
-			try { UserLocalServiceUtil.getService(); }
-			catch (Exception e) {
-				_log.warn("Stopping session polling as you are in dev mode (I think, am I wrong?)");
-				return new SessionInfoBean("","", true); //tells that you are in development mode 
-			}	
+		SessionManager manager = SessionManager.getInstance();
+		if (manager == null) {
 			_log.warn("Liferay Portal Detected but session Expired");
 			return new SessionInfoBean("",""); //tells session expired
 		}
-
+		ASLSession session = null;
+		try { 
+			session = getASLSession();
+			if (session == null || session.getUsername() == null) {
+				UserLocalServiceUtil.getService();
+				_log.warn("Liferay Portal Detected but session Expired");
+				return new SessionInfoBean("",""); //tells session expired
+			}
+		}
+		catch (Exception e) {
+			_log.warn("Stopping session polling as you are in dev mode (am I wrong?)");
+			e.printStackTrace();
+			return new SessionInfoBean("","", true); //tells that you are in development mode 
+		}	
 		String user = session.getUsername();
 		String scope = session.getScope();
-
-		//check devMode
-		if (user == null && isFirstTime()) {
-			_log.warn("Stopping session polling as you are in dev mode (I think, am I wrong?)");		
-			return new SessionInfoBean("","", true); //tells that you are in development mode (you must be unless you're session expires in less than a minute)	
-		}		
 		//else
-		setFirstTimeCheck(false);
 		_log.trace("Session check OK for " + user + " at " + new Date());
 		if (user == null || user.compareTo("") == 0) {
 			_log.warn("User is null at " + new Date());			
@@ -71,21 +68,4 @@ public class SessionCheckerServiceImpl extends RemoteServiceServlet implements
 		return new SessionInfoBean(session.getUsername(), session.getScope());
 	}
 
-	private void setFirstTimeCheck(boolean isFirstTime) {
-		ASLSession session = getASLSession();
-		_log.trace("setFirstTimeCheck " + isFirstTime);
-		if (session != null) {
-			session.setAttribute(FIRST_TIME, isFirstTime);
-			if (isFirstTime) {
-				long expiryTime = session.increaseSessionTimeout(350000, true); //bit more than 5 minutes
-				_log.trace("asl timeout increased by 5 minutes, ASL to expire at " +  new Date(new Date().getTime()+expiryTime));
-			}
-		}
-	}
-
-	private Boolean isFirstTime() {
-		Boolean toReturn =  (Boolean) getASLSession().getAttribute(FIRST_TIME);
-		_log.trace("isFirstTime() " + toReturn);
-		return toReturn;
-	}
 }
